All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH] cpuidle/powernv: Read target_residency value of idle states from DT if available
@ 2015-01-19 11:32 ` Preeti U Murthy
  0 siblings, 0 replies; 12+ messages in thread
From: Preeti U Murthy @ 2015-01-19 11:32 UTC (permalink / raw)
  To: rafael.j.wysocki; +Cc: linux-pm, benh, linux-kernel, mpe, svaidy, linuxppc-dev

The device tree now exposes the residency values for different idle states. Read
these values instead of calculating residency from the latency values. The values
exposed in the DT are validated for optimal power efficiency. However to maintain
compatibility with the older firmware code which does not expose residency
values, use default values as a fallback mechanism. While at it, clump
the common parts of device tree parsing into one chunk.

Signed-off-by: Preeti U Murthy <preeti@linux.vnet.ibm.com>
---

 drivers/cpuidle/cpuidle-powernv.c |   39 ++++++++++++++++++++++++-------------
 1 file changed, 25 insertions(+), 14 deletions(-)

diff --git a/drivers/cpuidle/cpuidle-powernv.c b/drivers/cpuidle/cpuidle-powernv.c
index 2726663..9e732e1 100644
--- a/drivers/cpuidle/cpuidle-powernv.c
+++ b/drivers/cpuidle/cpuidle-powernv.c
@@ -162,7 +162,8 @@ static int powernv_add_idle_states(void)
 	int dt_idle_states;
 	const __be32 *idle_state_flags;
 	const __be32 *idle_state_latency;
-	u32 len_flags, flags, latency_ns;
+	const __be32 *idle_state_residency;
+	u32 len_flags, flags, latency_ns, residency_ns;
 	int i;
 
 	/* Currently we have snooze statically defined */
@@ -186,14 +187,21 @@ static int powernv_add_idle_states(void)
 		return nr_idle_states;
 	}
 
+	idle_state_residency = of_get_property(power_mgt,
+			"ibm,cpu-idle-state-residency-ns", NULL);
+	if (!idle_state_residency) {
+		pr_warn("DT-PowerMgmt: missing ibm,cpu-idle-state-residency-ns\n");
+		pr_warn("Falling back to default values\n");
+	}
+
 	dt_idle_states = len_flags / sizeof(u32);
 
 	for (i = 0; i < dt_idle_states; i++) {
 
 		flags = be32_to_cpu(idle_state_flags[i]);
-
-		/* Cpuidle accepts exit_latency in us and we estimate
-		 * target residency to be 10x exit_latency
+		/*
+		 * Cpuidle accepts exit_latency and target_residency in us.
+		 * Use default target_residency values if f/w does not expose it.
 		 */
 		latency_ns = be32_to_cpu(idle_state_latency[i]);
 		if (flags & OPAL_PM_NAP_ENABLED) {
@@ -201,12 +209,8 @@ static int powernv_add_idle_states(void)
 			strcpy(powernv_states[nr_idle_states].name, "Nap");
 			strcpy(powernv_states[nr_idle_states].desc, "Nap");
 			powernv_states[nr_idle_states].flags = 0;
-			powernv_states[nr_idle_states].exit_latency =
-					((unsigned int)latency_ns) / 1000;
-			powernv_states[nr_idle_states].target_residency =
-					((unsigned int)latency_ns / 100);
+			powernv_states[nr_idle_states].target_residency = 100;
 			powernv_states[nr_idle_states].enter = &nap_loop;
-			nr_idle_states++;
 		}
 
 		if (flags & OPAL_PM_SLEEP_ENABLED ||
@@ -215,13 +219,20 @@ static int powernv_add_idle_states(void)
 			strcpy(powernv_states[nr_idle_states].name, "FastSleep");
 			strcpy(powernv_states[nr_idle_states].desc, "FastSleep");
 			powernv_states[nr_idle_states].flags = CPUIDLE_FLAG_TIMER_STOP;
-			powernv_states[nr_idle_states].exit_latency =
-					((unsigned int)latency_ns) / 1000;
-			powernv_states[nr_idle_states].target_residency =
-					((unsigned int)latency_ns / 100);
+			powernv_states[nr_idle_states].target_residency = 300000;
 			powernv_states[nr_idle_states].enter = &fastsleep_loop;
-			nr_idle_states++;
 		}
+
+		powernv_states[nr_idle_states].exit_latency =
+				((unsigned int)latency_ns) / 1000;
+
+		if (idle_state_residency) {
+			residency_ns = be32_to_cpu(idle_state_residency[i]);
+			powernv_states[nr_idle_states].target_residency =
+				((unsigned int)residency_ns) / 1000;
+		}
+
+		nr_idle_states++;
 	}
 
 	return nr_idle_states;


^ permalink raw reply related	[flat|nested] 12+ messages in thread
* PowerMac G5 Quad Issue reporting
@ 2015-01-20 14:36 luigi burdo
  0 siblings, 0 replies; 12+ messages in thread
From: luigi burdo @ 2015-01-20 14:36 UTC (permalink / raw)
  To: linuxppc-dev, linux-kernel

[-- Attachment #1: Type: text/plain, Size: 1241 bytes --]

Hello all LinuxPPc Developer,
need to report a issue that im facing from kernel 3.16 and up.

The fans of powermac g5 quad start boosting like a turbo jet after the system is 
been loaded and up. 
Usually this become after about 30-60 seconds when the system is loaded.
This issue start with Xorg loaded or only in teminal system (gdm3 not loaded)
This issue come with system load with minimum cpu usage  5%  and less too.
During the closing of the system (reboot) the fans goes in right silents mode.


I had been tested and compiled the kernel with all the modules of fan controls for Apple G5 
without a positive result.
Kernel tested 3.16.ctk2 (debian wheezy 7.8), 3.18.3 and  3.19.rc5
Im using Debian Wheezy 7.6 (up 7.8) PPC on Quad G5 (970mp) Nvidia 7800gtx and RadeonHD 6570

Dont face this issue with old kernels version 3.10.65 and pre
(didnt test the 3.12 and 3.14) 

Need to report to Michel D. from amd.com . The RadeonHD 6570 now is working on PowerMac G5 too
look like the Xorg bigendian  issue related Evergreen / Northern  is been fixed ;-)


Thanks alot for your jobs guys
Hope soon i will able to help in X5000 hardware too 
PPC Rulez ... and sorry for my "perfect english"
Luigi Burdo 		 	   		  

[-- Attachment #2: Type: text/html, Size: 1535 bytes --]

^ permalink raw reply	[flat|nested] 12+ messages in thread

end of thread, other threads:[~2015-01-27  6:28 UTC | newest]

Thread overview: 12+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2015-01-19 11:32 [PATCH] cpuidle/powernv: Read target_residency value of idle states from DT if available Preeti U Murthy
2015-01-19 11:32 ` Preeti U Murthy
2015-01-20  5:45 ` Michael Ellerman
2015-01-20  5:45   ` Michael Ellerman
2015-01-20 11:26   ` Preeti U Murthy
2015-01-20 11:52     ` PowerMac G5 Quad Issue reporting luigi burdo
2015-01-21  6:39       ` Michel Dänzer
2015-01-21  8:13         ` luigi burdo
2015-01-23  4:59     ` cpuidle/powernv: Read target_residency value of idle states from DT if available Michael Ellerman
2015-01-27  4:02       ` Preeti U Murthy
2015-01-27  6:28         ` Michael Ellerman
2015-01-20 14:36 PowerMac G5 Quad Issue reporting luigi burdo

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.